pub fn spawn<F: SpawnableNoReturn>(future: F)Expand description
Spawns a future on the underlying runtime in a cross platform way (NB: the Send bound is removed in WASM)
pub fn spawn<F: SpawnableNoReturn>(future: F)Spawns a future on the underlying runtime in a cross platform way (NB: the Send bound is removed in WASM)