pub trait SpawnableNoReturn:
'static
+ Send
+ Future<Output = ()> { }Expand description
An async function that is able to be spawned, lowest common denominator as we cannot have a return type on WASM
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".