SpawnableNoReturn

Trait SpawnableNoReturn 

pub trait SpawnableNoReturn:
    'static
    + Send
    + Future<Output = ()> { }
An async function that is able to be spawned, lowest common denominator as we cannot have a return type on WASM

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: 'static + Send + Future<Output = ()> + ?Sized> SpawnableNoReturn for T